# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['IAMAccessKeyArgs', 'IAMAccessKey']

@pulumi.input_type
class IAMAccessKeyArgs:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[str]] = None,
                 operations: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a IAMAccessKey resource.
        :param pulumi.Input[str] name: The IAM access key name.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] operations: A list of API operations to restrict the key to.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] resources: A list of API [resources][iam-resource] to restrict the key to (`<domain>/<type>:<name>`).
        :param pulumi.Input[Sequence[pulumi.Input[str]]] tags: A list of tags to restrict the key to.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if operations is not None:
            pulumi.set(__self__, "operations", operations)
        if resources is not None:
            pulumi.set(__self__, "resources", resources)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The IAM access key name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def operations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of API operations to restrict the key to.
        """
        return pulumi.get(self, "operations")

    @operations.setter
    def operations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "operations", value)

    @property
    @pulumi.getter
    def resources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of API [resources][iam-resource] to restrict the key to (`<domain>/<type>:<name>`).
        """
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "resources", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of tags to restrict the key to.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _IAMAccessKeyState:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 operations: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 secret: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags_operations: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering IAMAccessKey resources.
        :param pulumi.Input[str] key: The IAM access key (identifier).
        :param pulumi.Input[str] name: The IAM access key name.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] operations: A list of API operations to restrict the key to.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] resources: A list of API [resources][iam-resource] to restrict the key to (`<domain>/<type>:<name>`).
        :param pulumi.Input[str] secret: (Sensitive) The key secret.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] tags: A list of tags to restrict the key to.
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if operations is not None:
            pulumi.set(__self__, "operations", operations)
        if resources is not None:
            pulumi.set(__self__, "resources", resources)
        if secret is not None:
            pulumi.set(__self__, "secret", secret)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if tags_operations is not None:
            pulumi.set(__self__, "tags_operations", tags_operations)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[str]]:
        """
        The IAM access key (identifier).
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The IAM access key name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def operations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of API operations to restrict the key to.
        """
        return pulumi.get(self, "operations")

    @operations.setter
    def operations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "operations", value)

    @property
    @pulumi.getter
    def resources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of API [resources][iam-resource] to restrict the key to (`<domain>/<type>:<name>`).
        """
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "resources", value)

    @property
    @pulumi.getter
    def secret(self) -> Optional[pulumi.Input[str]]:
        """
        (Sensitive) The key secret.
        """
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secret", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of tags to restrict the key to.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="tagsOperations")
    def tags_operations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "tags_operations")

    @tags_operations.setter
    def tags_operations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "tags_operations", value)


class IAMAccessKey(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 operations: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Create a IAMAccessKey resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: The IAM access key name.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] operations: A list of API operations to restrict the key to.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] resources: A list of API [resources][iam-resource] to restrict the key to (`<domain>/<type>:<name>`).
        :param pulumi.Input[Sequence[pulumi.Input[str]]] tags: A list of tags to restrict the key to.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[IAMAccessKeyArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a IAMAccessKey resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param IAMAccessKeyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IAMAccessKeyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 operations: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IAMAccessKeyArgs.__new__(IAMAccessKeyArgs)

            __props__.__dict__["name"] = name
            __props__.__dict__["operations"] = operations
            __props__.__dict__["resources"] = resources
            __props__.__dict__["tags"] = tags
            __props__.__dict__["key"] = None
            __props__.__dict__["secret"] = None
            __props__.__dict__["tags_operations"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["key", "secret"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(IAMAccessKey, __self__).__init__(
            'exoscale:index/iAMAccessKey:IAMAccessKey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            key: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            operations: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            resources: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            secret: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            tags_operations: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'IAMAccessKey':
        """
        Get an existing IAMAccessKey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] key: The IAM access key (identifier).
        :param pulumi.Input[str] name: The IAM access key name.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] operations: A list of API operations to restrict the key to.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] resources: A list of API [resources][iam-resource] to restrict the key to (`<domain>/<type>:<name>`).
        :param pulumi.Input[str] secret: (Sensitive) The key secret.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] tags: A list of tags to restrict the key to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IAMAccessKeyState.__new__(_IAMAccessKeyState)

        __props__.__dict__["key"] = key
        __props__.__dict__["name"] = name
        __props__.__dict__["operations"] = operations
        __props__.__dict__["resources"] = resources
        __props__.__dict__["secret"] = secret
        __props__.__dict__["tags"] = tags
        __props__.__dict__["tags_operations"] = tags_operations
        return IAMAccessKey(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def key(self) -> pulumi.Output[str]:
        """
        The IAM access key (identifier).
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The IAM access key name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def operations(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        A list of API operations to restrict the key to.
        """
        return pulumi.get(self, "operations")

    @property
    @pulumi.getter
    def resources(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        A list of API [resources][iam-resource] to restrict the key to (`<domain>/<type>:<name>`).
        """
        return pulumi.get(self, "resources")

    @property
    @pulumi.getter
    def secret(self) -> pulumi.Output[str]:
        """
        (Sensitive) The key secret.
        """
        return pulumi.get(self, "secret")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        A list of tags to restrict the key to.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="tagsOperations")
    def tags_operations(self) -> pulumi.Output[Sequence[str]]:
        return pulumi.get(self, "tags_operations")

